import plotly.graph_objects as go
import pandas as pd
import numpy as np

df = pd.read_excel("example_data.xlsx")
df.head()

num_rows = len(df)
nan_rows = df[df["Timestamp"].isnull()]
info_rows = df[num_rows - 3 :]

df.drop(nan_rows.index, inplace=True)
df.drop(info_rows.index, inplace=True)

headers = list(df.columns.values)
num_cols = len(headers)
num_measurements = 4
ids = ["ABC123", "DEF456", "GHI789"]
measurement_names = ["Measurement 1", "Measurement 2", "Measurement 3", "Measurement 4"]
true_headers = ["Temperature (C)", "CO2", "Agitation", "pH"]
num_of_dfs = (num_cols - 1) / num_measurements


def split_df(num_of_dfs, df, num_measurements):
    dfs = list(range(4))
    start = 1
    end = num_measurements + 1
    for i in range(int(num_of_dfs)):
        dfs[i] = df[headers[start:end]]
        start += num_measurements
        end += num_measurements

        for j in range(int(num_measurements) - 1):
            dfs[i].columns = true_headers
            dfs[i].rename(
                columns={f"{ids[j]} - {measurement_names[j]}": f"{true_headers[j]}"},
                inplace=True,
            )
    return dfs


# log each column in the dfs
def log_dfs(dfs):
    for i in range(int(num_of_dfs)):
        for j in range(int(num_measurements)):
            dfs[i][true_headers[j]] = np.log2(dfs[i][true_headers[j]].astype(float))


def plot_line(id, measurements, log=False):
    dfs = split_df(num_of_dfs, df, num_measurements)
    if log:
        log_dfs(dfs)

    index = ids.index(id)
    fig = go.Figure()
    for i in range(len(measurements)):
        fig.add_trace(
            go.Scatter(
                x=df["Timestamp"], y=dfs[index][measurements[i]], name=measurements[i]
            )
        )
    fig.show()
